%define upstream_name    JSON-DWIW
%define upstream_version 0.47

%{?perl_default_filter}

Name:		perl-%{upstream_name}
Version:	%perl_convert_version %{upstream_version}
Release:	%mkrel 22

Summary:	Return a true or false value when
License:	GPL+ or Artistic
Group:		Development/Perl
Url:		https://metacpan.org/release/%{upstream_name}
Source0:	https://cpan.metacpan.org/modules/by-module/JSON/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires:	perl-devel


%description
Other JSON modules require setting several parameters before calling the
conversion methods to do what I want. This module does things by default
that I think should be done when working with JSON in Perl. This module
also encodes and decodes faster than JSON.pm and JSON::Syck in my
benchmarks.

This means that any piece of data in Perl (assuming it's valid unicode)
will get converted to something in JSON instead of throwing an exception.
It also means that output will be strict JSON, while accepted input will be
flexible, without having to set any options.

Encoding
    Perl objects get encoded as their underlying data structure, with the
    exception of Math::BigInt and Math::BigFloat, which will be output as
    numbers, and JSON::DWIW::Boolean, which will get output as a true or
    false value (see the true() and false() methods). For example, a
    blessed hash ref will be represented as an object in JSON, a blessed
    array will be represented as an array. etc. A reference to a scalar is
    dereferenced and represented as the scalar itself. Globs, Code refs,
    etc., get stringified, and undef becomes null.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

# fix build on aarch64
cp -af %{_rpmconfigdir}/%{_real_vendor}/config.{guess,sub} libjsonevt/

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%make_install

%files
%doc README META.yml
%{_mandir}/man3/*
%perl_vendorarch/JSON
%perl_vendorarch/auto/JSON


%changelog
* Wed Jun 17 2020 umeabot <umeabot> 0.470.0-22.mga8
+ Revision: 1594828
- Rebuild for perl 5.32

* Sun Feb 16 2020 umeabot <umeabot> 0.470.0-21.mga8
+ Revision: 1529602
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Tue Aug 27 2019 tmb <tmb> 0.470.0-20.mga8
+ Revision: 1433719
- rebuild for perl 5.30

* Tue Aug 27 2019 tv <tv> 0.470.0-19.mga8
+ Revision: 1433276
- rebuild with perl-5.30

* Fri Sep 21 2018 umeabot <umeabot> 0.470.0-18.mga7
+ Revision: 1293227
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 pterjan <pterjan> 0.470.0-17.mga7
+ Revision: 1249130
- Rebuild for perl 5.28

* Mon Jun 25 2018 wally <wally> 0.470.0-16.mga7
+ Revision: 1239648
- fix build on aarch64

* Tue Oct 03 2017 tv <tv> 0.470.0-15.mga7
+ Revision: 1165038
- rebuild with fixed rpm for missing autodeps

* Thu Aug 31 2017 pterjan <pterjan> 0.470.0-14.mga7
+ Revision: 1149001
- Rebuild for perl ABI changes

* Sat Jul 22 2017 neoclust <neoclust> 0.470.0-13.mga7
+ Revision: 1126669
- Rebuild against new Perl 5.26

* Sun Jun 19 2016 pterjan <pterjan> 0.470.0-12.mga6
+ Revision: 1028836
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 0.470.0-11.mga6
+ Revision: 957580
- Mageia 6 Mass Rebuild

* Thu Jun 25 2015 sander85 <sander85> 0.470.0-10.mga6
+ Revision: 843120
- Rebuild for perl 5.22

* Wed Oct 15 2014 umeabot <umeabot> 0.470.0-9.mga5
+ Revision: 750787
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.470.0-8.mga5
+ Revision: 685141
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 pterjan <pterjan> 0.470.0-7.mga5
+ Revision: 631322
- Rebuild for perl 5.20

* Sat Oct 19 2013 umeabot <umeabot> 0.470.0-6.mga4
+ Revision: 524369
- Mageia 4 Mass Rebuild

* Wed May 29 2013 jquelin <jquelin> 0.470.0-5.mga4
+ Revision: 430766
- perl 5.18.0 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.470.0-4.mga3
+ Revision: 368763
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed May 30 2012 jquelin <jquelin> 0.470.0-3.mga3
+ Revision: 250794
- rebuild for perl 5.16

* Sun Jun 12 2011 sander85 <sander85> 0.470.0-2.mga2
+ Revision: 104713
- Rebuild for perl 5.14

* Fri Jan 21 2011 jquelin <jquelin> 0.470.0-1.mga1
+ Revision: 30634
- mageia rebuild
- imported package perl-JSON-DWIW

